@@ -51,6 +51,10 @@ class user():
 
     self.achievements = self.user["achievements"]
 
+  def addData(self,name,data):
+    setattr(self, name, data)
+    self.user[name] = data
+
   def getItem(self,iid):
     return self.items[iid]
 
